==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebActiveNodeChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveNodeChangeEventArgsDetailDescriptionMetadata } from "./WebActiveNodeChangeEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDescription } from "./WebActiveNodeChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebActiveNodeChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveNodeChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveNodeChangeEventArgsDescriptionMetadata.a == null) {
                WebActiveNodeChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveNodeChangeEventArgsDescriptionMetadata.c(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActiveNodeChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            WebActiveNodeChangeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebActiveNodeChangeEventArgsDetail");
        }
        static d(a) {
            WebActiveNodeChangeEventArgsDescriptionMetadata.b(a);
            a.ad("WebActiveNodeChangeEventArgs", () => new WebActiveNodeChangeEventArgsDescription());
            a.ac("WebActiveNodeChangeEventArgs", WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebActiveNodeChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveNodeChangeEventArgsDescriptionMetadata, 'WebActiveNodeChangeEventArgsDescriptionMetadata');
    WebActiveNodeChangeEventArgsDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebActiveNodeChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveNodeChangeEventArgsDetailDescriptionMetadata } from "./WebActiveNodeChangeEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDescription } from "./WebActiveNodeChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebActiveNodeChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveNodeChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveNodeChangeEventArgsDescriptionMetadata.a == null) {
                WebActiveNodeChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveNodeChangeEventArgsDescriptionMetadata.c(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActiveNodeChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            WebActiveNodeChangeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebActiveNodeChangeEventArgsDetail");
        }
        static d(a) {
            WebActiveNodeChangeEventArgsDescriptionMetadata.b(a);
            a.ae("WebActiveNodeChangeEventArgs", () => new WebActiveNodeChangeEventArgsDescription());
            a.ad("WebActiveNodeChangeEventArgs", WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebActiveNodeChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveNodeChangeEventArgsDescriptionMetadata, 'WebActiveNodeChangeEventArgsDescriptionMetadata');
    WebActiveNodeChangeEventArgsDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDescriptionMetadata;
})();
